Closed (fixed)
Project:
Drupal core
Version:
8.7.x-dev
Component:
file.module
Priority:
Normal
Category:
Task
Assigned:
Unassigned
Issue tags:
Reporter:
Created:
16 Apr 2019 at 07:09 UTC
Updated:
10 Jun 2019 at 07:09 UTC
Jump to comment: Most recent, Most recent file
Comments
Comment #2
claudiu.cristeaThis patch decreases the locally test run from 7.0 to 1.6 seconds.
Comment #3
lendudeSame patch rolled with -M10% to detect the move and make reviewing easier.
Comment #4
lendudeConversion looks good, I don't see any loss of coverage and nice to see clearer naming of the created test files.
Comment #5
catchThis should use gender neutral language (and will fail the coder rule just added), but also just doesn't need a comment at all since the code following is self-explanatory.
Comment #6
claudiu.cristeaRemoved the line.
Comment #7
johnwebdev commentedFeedback has been adressed :)
Comment #9
larowlanCommitted 2adeb97 and pushed to 8.8.x. Thanks!
C/p as 13cc9de963 and pushed to 8.7.x